@@ -5,16 +5,17 @@ dgl <- function(x,lambda1=0,lambda2=NULL,lambda3=NULL,lambda4=NULL,param="fkml",
 lambdas <- .gl.parameter.tidy(lambda1,lambda2,lambda3,lambda4,param,lambda5)
 # Check the parameters
 if(!gl.check.lambda(lambdas,param=param,vect=TRUE)) {
-        stop(paste("The parameter values", lambdas,
-"\ndo not produce a proper distribution with the",param,
-"parameterisation - see \ndocumentation for gl.check.lambda"))
-        }
+  stop(paste("The parameter values (", paste(lambdas,collapse=", "),
+             ")\ndo not produce a proper distribution with the ",param,
+             " parameterisation - see \ndocumentation for gl.check.lambda",sep=""))
+}
 # calculate u=F(x) numerically, then use qdgl
 # Unless x is outside the range, then density should be zero
 extreme<-qgl(c(0,1),lambda1=lambdas,param=param)
 # It may be better to change this to simply  
 # (x <= extreme[2])*(x >= extreme[1])
 outside.range <- !as.logical((x<=extreme[2])*(x>=extreme[1]))
+# possibly calculate the end points here, rather than in the C code?
 u <- pgl(x,lambdas,param=param,inverse.eps=inverse.eps,max.iterations=max.iterations)
 dens <- dqgl(u,lambda1=lambdas,param=param)
 dens[outside.range] <- 0
@@ -24,17 +25,15 @@ dens
 pgl <- function(q,lambda1=0,lambda2=NULL,lambda3=NULL,lambda4=NULL,param="fkml",
     lambda5=NULL,inverse.eps=.Machine$double.eps,max.iterations=500)
 {
-# Thanks to Steve Su, <s.su@qut.edu.au>, for improvements to this code
-# If lambda1 is a vector, the default value for lambda2 will cause a problem.
-# I did have a warning about this, but it will occur too often to make up for the benefit, so I've deleted it.
+# Thanks to Steve Su, see GLDEX package for contact details, for improvements to this code
 # Tidy the parameters so gl.check.lambda will work
 lambdas <- .gl.parameter.tidy(lambda1,lambda2,lambda3,lambda4,param,lambda5)
 # Check the parameters
 if(!gl.check.lambda(lambdas,param=param,vect=TRUE)) {
-	stop(paste("The parameter values", lambda1, lambda2, lambda3,lambda4,
-    	"\ndo not produce a proper distribution with the",param,
-    	"parameterisation - see \ndocumentation for gl.check.lambda"))
-    	} 
+  stop(paste("The parameter values (", paste(lambdas,collapse=", "),
+             ")\ndo not produce a proper distribution with the ",param,
+             " parameterisation - see \ndocumentation for gl.check.lambda",sep=""))
+}
 jr <- q; jr[sort.list(q)] <- seq(along=q) 
 order.x<-order(q) 
 xx<-sort(q) 
@@ -74,10 +73,16 @@ result <- switch(param,
 		lambdas[4],lambdas[5], 
     		as.double(0),as.double(1),inverse.eps,
 		as.integer(max.iterations),as.double(q),as.double(u),
-		as.integer(length.of.vector),
-		PACKAGE="gld"),
-    	stop("Error: Parameterisation must be one of fmkl, fm5 or rs") 
-    	) # closes "switch" 
+		as.integer(length.of.vector),PACKAGE="gld"),
+    VSK=,
+    gpd=,
+    GPD=,
+    vsk=.C("gl_vsk_distfunc",lambdas[1],lambdas[2],lambdas[3],lambdas[4],
+        as.double(0),as.double(1),inverse.eps,
+        as.integer(max.iterations),as.double(q),as.double(u),
+        as.integer(length.of.vector),PACKAGE="gld"),
+    stop("Error: Parameterisation must be one of fmkl, rs, fm5 or vsk")
+    	) # closes "switch"
 if (!(is.numeric(result[[1]]))){ 
 	stop("Values for quantiles outside range. This shouldn't happen") 
 } 
